@@ -326,21 +326,38 @@ static OP *S_gen_field_init_op(pTHX_ FieldMeta *fieldmeta)
             newSVpvf("Required parameter '%" SVf "' is missing for %" SVf " constructor",
               SVfARG(paramname), SVfARG(classmeta->name)));
 
-        valueop = newCONDOP(0,
-          /* exists $params{$paramname} */
-          newUNOP(OP_EXISTS, 0,
-            newBINOP(OP_HELEM, 0,
-              newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
-              newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
+        if(fieldmeta->def_if_undef)
+          /* delete $params{$paramname} // valueop */
+          valueop = newLOGOP(OP_DOR, 0,
+            newUNOP(OP_DELETE, 0,
+              newBINOP(OP_HELEM, 0,
+                newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
+                newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
 
-          /* ? delete $params{$paramname} */
-          newUNOP(OP_DELETE, 0,
-            newBINOP(OP_HELEM, 0,
-              newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
-              newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
+            valueop);
+        else if(fieldmeta->def_if_false)
+          /* delete $params{$paramname} || valueop */
+          valueop = newLOGOP(OP_OR, 0,
+            newUNOP(OP_DELETE, 0,
+              newBINOP(OP_HELEM, 0,
+                newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
+                newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
 
-          /* : valueop or die */
-          valueop);
+            valueop);
+        else
+          /* exists $params{$paramname} ? delete $params{$paramname} : valueop */
+          valueop = newCONDOP(0,
+            newUNOP(OP_EXISTS, 0,
+              newBINOP(OP_HELEM, 0,
+                newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
+                newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
+
+            newUNOP(OP_DELETE, 0,
+              newBINOP(OP_HELEM, 0,
+                newPADxVOP(OP_PADHV, OPf_REF, PADIX_PARAMS),
+                newSVOP(OP_CONST, 0, SvREFCNT_inc(paramname)))),
+
+            valueop);
       }
 
       if(valueop)
